%global modname virtualenvwrapper
%global desc virtualenvwrapper is a set of extensions to Ian Bicking's \
`virtualenv <http://pypi.python.org/pypi/virtualenv>`_ tool.  The extensions \
include wrappers for creating and deleting virtual environments and otherwise \
managing your development workflow, making it easier to work on more than \
one project at a time without introducing conflicts in their dependencies.
%global sum Enhancements to virtualenv

Name:             python-%{modname}
Version:          4.7.2
Release:          3%{?dist}
Summary:          %{sum}

Group:            Development/Languages
License:          MIT
URL:              http://pypi.python.org/pypi/%{modname}
Source0:          http://pypi.python.org/packages/source/v/%{modname}/%{modname}-%{version}.tar.gz

BuildArch:        noarch

BuildRequires:      python2-devel
BuildRequires:      python2-setuptools
BuildRequires:      python2-virtualenv
BuildRequires:      python2-virtualenv-clone
BuildRequires:      python2-stevedore
BuildRequires:      python2-pbr

BuildRequires:      python3-devel
BuildRequires:      python3-setuptools
BuildRequires:      python3-virtualenv
BuildRequires:      python3-virtualenv-clone
BuildRequires:      python3-stevedore
BuildRequires:      python3-pbr

## Just for tests
#BuildRequires:      python-tox
#BuildRequires:      ksh
#BuildRequires:      zsh

%description
%{desc}

%package -n python2-%{modname}
Summary:            %{sum}
Requires:           python2-virtualenv
Requires:           python2-virtualenv-clone
Requires:           python2-stevedore
%{?python_provide:%python_provide python2-%{modname}}

%description -n python2-%{modname}
%{desc}


%package -n python3-%{modname}
Summary:            %{sum}
Requires:           python3-virtualenv
Requires:           python3-virtualenv-clone
Requires:           python3-stevedore
%{?python_provide:%python_provide python3-%{modname}}

%description -n python3-%{modname}
%{desc}

%prep
%setup -q -n %{modname}-%{version}
rm -rf %{modname}.egg-info

%build
%py2_build
%py3_build

%install
%py2_install
%py3_install

%{__mkdir_p} %{buildroot}/%{_sysconfdir}/profile.d/
ln -s %{_bindir}/virtualenvwrapper_lazy.sh %{buildroot}/%{_sysconfdir}/profile.d/virtualenvwrapper.sh

#%%check
# Tests won't fly in koji since they try to install stuff from pypi
#tox -e py27

%files -n python2-%{modname}
%doc PKG-INFO docs
%{python2_sitelib}/%{modname}
%{python2_sitelib}/%{modname}-%{version}*
%{_bindir}/virtualenvwrapper.sh
%{_bindir}/virtualenvwrapper_lazy.sh
%config(noreplace) %{_sysconfdir}/profile.d/virtualenvwrapper.sh

%files -n python3-%{modname}
%doc PKG-INFO docs
%{python3_sitelib}/%{modname}
%{python3_sitelib}/%{modname}-%{version}*
%{_bindir}/virtualenvwrapper.sh
%{_bindir}/virtualenvwrapper_lazy.sh
%config(noreplace) %{_sysconfdir}/profile.d/virtualenvwrapper.sh

%changelog
* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.7.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 4.7.2-2
- Rebuild for Python 3.6

* Sat Aug 27 2016 Kevin Fenzi <kevin@scrye.com> - 4.7.2-1
- Update to 4.7.2. Fixes bug #1370847

* Mon Jul 25 2016 Lumir Balhar <lbalhar@redhat.com> - 4.7.1-5
- Python2/3 subpackages

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.7.1-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Jul 11 2016 Ralph Bean <rbean@redhat.com> - 4.7.1-3
- Add dep on which for #1354506.

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Sep 19 2015 Ralph Bean <rbean@redhat.com> - 4.7.1-1
- new version

* Wed Jun 17 2015 Ralph Bean <rbean@redhat.com> - 4.6.0-1
- new version

* Wed Apr 29 2015 Ralph Bean <rbean@redhat.com> - 4.5.1-1
- new version

* Mon Apr 27 2015 Ralph Bean <rbean@redhat.com> - 4.5.0-1
- new version

* Mon Apr 27 2015 Ralph Bean <rbean@redhat.com> - 4.3.2-2
- Use virtualenvwrapper_lazy.sh by default, fixing #1213121.

* Wed Feb 18 2015 Ralph Bean <rbean@redhat.com> - 4.3.2-1
- new version

* Thu Jul 24 2014 Ralph Bean <rbean@redhat.com> - 4.3.1-1
- Latest upstream.

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Jan 29 2014 Ralph Bean <rbean@redhat.com> - 4.2-2
- Add a symlink to /etc/profile.d/ so that the package works out of the box.

* Tue Jan 28 2014 Ralph Bean <rbean@redhat.com> - 4.2-1
- Latest upstream

* Wed Dec 04 2013 Ralph Bean <rbean@redhat.com> - 4.1.1-2
- BuildRequires on python-pbr

* Wed Dec 04 2013 Ralph Bean <rbean@redhat.com> - 4.1.1-1
- Latest upstream.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Apr 29 2013 Ralph Bean <rbean@redhat.com> - 4.0-1
- Latest upstream including the following:
- The python modules for extensions are now always run with
  PWD=$WORKON_HOME (previously the value of PWD varied depending
  on the hook). The shell portion of any hook (anything sourced
  by the user’s shell when the hook is run) is still run in the
  same place as before.
- Fix the name of the script in an error message produced by
  virtualenvwrapper_lazy.sh.

* Mon Apr 08 2013 Ralph Bean <rbean@redhat.com> - 3.7.1-1
- Latest upstream including the following bugfix changes.
- Rename functions for generating help so they do not pollute the global
  namespace, and especially so they do not interfere with tab completion.
  Contributed by davidszotten.
- Fix an issue with listing project templates if none are installed.
  (issue 179)
- Fix an issue with the --python option to mkvirtualenv becoming sticky
  for future calls that do not explicitly specify the option. (issue 178)

* Wed Mar 20 2013 Ralph Bean <rbean@redhat.com> - 3.7-1
- Latest upstream.
- Improve tab-completion support for users of the lazy-loading mode.
- Add --help option to mkproject.
- Add --help option to workon.
- Turn off logging from the hook loader by default.
- Use flake8 for style checking.

* Fri Mar 08 2013 Ralph Bean <rbean@redhat.com> - 3.6.1-1
- Latest upstream

* Mon Feb 25 2013 Ralph Bean <rbean@redhat.com> - 3.6-1
- Latest upstream

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 16 2012 Ralph Bean <rbean@redhat.com> 3.5-2
- Added new dependency on python-virtualenv-clone

* Mon Jul 09 2012 Ralph Bean <rbean@redhat.com> 3.5-1
- Latest upstream version.

* Fri May 25 2012 Ralph Bean <rbean@redhat.com> 3.4-1
- New upstream release with security fix and new features.
- Packaging new file virtualenvwrapper_lazy.sh
- More explicit directory ownership in python_sitelib.
- Removed old patches due to upstream bugfixes.
- Using modname macro in Source url.

* Mon May 07 2012 Ralph Bean <rbean@redhat.com> 3.2-4
- Fixed a typo in the changelog

* Mon May 07 2012 Ralph Bean <rbean@redhat.com> 3.2-3
- Applied security patch from Aron Griffis.  http://bit.ly/IHJqxs

* Tue Apr 17 2012 Ralph Bean <rbean@redhat.com> 3.2-2
- Updated the Shebangs-and-permissions patch to add a shebang to
  /usr/bin/virtualenvwrapper.sh

* Mon Apr 09 2012 Ralph Bean <rbean@redhat.com> 3.2-1
- Packaged latest version which includes disambiguated license.
- Removed %defattr macro.
- Added patch to quiet up rpmlint.

* Wed Apr 04 2012 Ralph Bean <rbean@redhat.com> 3.1-1
- initial package for Fedora
